==> octoprint-1.11.3.tar.gz: octoprint-1.11.3/SUPPORTERS.md <==
# Supporters

Development of this version of OctoPrint wouldn't have been possible without
[the financial support by the community](https://support.octoprint.org) -
thanks to everyone who contributed!

## Patrons & Sponsors

  * 3D-TECH
  * 3DPrinterOS
  * Accalia Elementia
  * Alex Young
  * Anthony Gainsborough
  * Ash King
  * Boris Hussein
  * Brad Jackson
  * Bradford Benn
  * Bret Wortman
  * Christian Petropolis
  * Christian Wolf
  * Christian Würthner
  * Christoph Sigrist
  * Christopher Heiny
  * Coltarus Halo
  * CooperSpartan
  * David OMeara
  * David Pitman
  * DBDWJSasquatch_Printing_78
  * DeltaMaker 3D Printers
  * Dennis Breining
  * Dima Gorbenko
  * Dr. Frank Wester
  * Erik Ableson
  * Ernesto Martinez
  * Franziska Kunsmann
  * homoldak000
  * James Nangano
  * Jannis Leidel
  * Jason Kitchens
  * JCsGotThis
  * John Cassel
  * Justin Kaufman
  * Kaile Riser
  * Keenan Newton
  * Kenneth Jiang
  * Kurt Wubbels
  * Lachlan Bell
  * LulzBot
  * Makespace Madrid
  * Marco van Dijk
  * Mark Greenwald
  * Mark Robards
  * Mark Walker
  * Martin Schmitt
  * Matthias Urlichs
  * Michael Aumock
  * Michael Badagliacco
  * Mike Labanov
  * Norman Jaffe
  * Randy C. Will
  * Ranjib Dey
  * Richard Stocks
  * Rik KM
  * Robert Gusek
  * Sebastien Andrivet
  * SimplyPrint
  * Sinie47
  * Stefan Krister
  * TheWebMachine
  * Tideline 3D
  * Timothy Efinger
  * Ulrich Kempken

and 2496 more wonderful people pledging on the [Patreon campaign](https://patreon.com/foosel), on [GitHub Sponsors](https://github.com/users/foosel/sponsorship), via [Ko-fi](https://ko-fi.com/octoprint) or [Donorbox](https://donorbox.org/support-octoprint?recurring=true)!

==> octoprint-1.11.5.tar.gz: octoprint-1.11.5/SUPPORTERS.md <==
# Supporters

Development of this version of OctoPrint wouldn't have been possible without
[the financial support by the community](https://support.octoprint.org) -
thanks to everyone who contributed!

## Patrons & Sponsors

  * 3D-TECH
  * 3DPrinterOS
  * Accalia Elementia
  * Alex Young
  * Anthony Gainsborough
  * Ash King
  * Boris Hussein
  * Brad Jackson
  * Bradford Benn
  * Bret Wortman
  * Christian Petropolis
  * Christian Wolf
  * Christian Würthner
  * Christoph Sigrist
  * Christopher Heiny
  * Coltarus Halo
  * CooperSpartan
  * David OMeara
  * David Pitman
  * DeltaMaker 3D Printers
  * Dennis Breining
  * Dima Gorbenko
  * Dr. Frank Wester
  * Erik Ableson
  * Ernesto Martinez
  * Franziska Kunsmann
  * homoldak000
  * James Nangano
  * Jannis Leidel
  * Jason Kitchens
  * John Cassel
  * Justin Kaufman
  * Kaile Riser
  * Keenan Newton
  * Kurt Wubbels
  * Lachlan Bell
  * LulzBot
  * Makespace Madrid
  * Marco van Dijk
  * Mark Greenwald
  * Mark Robards
  * Mark Walker
  * Martin Schmitt
  * Matthias Urlichs
  * Michael Aumock
  * Michael Badagliacco
  * Michelle Tomasko
  * Norman Jaffe
  * Randy C. Will
  * Ranjib Dey
  * Richard Stocks
  * Rik KM
  * Robert Gusek
  * Sebastien Andrivet
  * SimplyPrint
  * Sinie47
  * Stefan Krister
  * Steve Dougherty
  * TheWebMachine
  * Tideline 3D
  * Timothy Efinger
  * Ulrich Kempken

and 2378 more wonderful people pledging on the [Patreon campaign](https://patreon.com/foosel), on [GitHub Sponsors](https://github.com/users/foosel/sponsorship), via [Ko-fi](https://ko-fi.com/octoprint) or [Donorbox](https://donorbox.org/support-octoprint?recurring=true)!
